@@ -4,6 +4,7 @@ import argparse
 
 from jira import JIRA
 
+logger = logging.getLogger()
 
 JIRA_USERNAME = os.getenv('JIRA_USERNAME')
 JIRA_TOKEN = os.getenv('JIRA_TOKEN')
@@ -26,5 +27,10 @@ def main():
     parser.add_argument('--task-id', required=True)
     parser.add_argument('--comment', required=True)
     args = parser.parse_args()
-    add_comment(args.server, args.task_id, args.comment)
+    try:
+        add_comment(args.server, args.task_id, args.comment)
+    except Exception as e:
+        logger.error("Unable to comment jira task")
+        logger.error(e)
+
 
